.. include:: global.rst.inc

.. api_reference:

=============
API Reference
=============

`watchdog.events`
=================

.. automodule:: watchdog.events


`watchdog.observers.api`
========================

.. automodule:: watchdog.observers.api
    :synopsis: Classes useful to observer implementers.

    Immutables
    ----------
    .. autoclass:: ObservedWatch
       :members:
       :show-inheritance:


    Collections
    -----------
    .. autoclass:: EventQueue
       :members:
       :show-inheritance:

    Classes
    -------
    .. autoclass:: EventEmitter
       :members:
       :show-inheritance:

    .. autoclass:: EventDispatcher
       :members:
       :show-inheritance:

    .. autoclass:: BaseObserver
       :members:
       :show-inheritance:



`watchdog.observers`
====================

.. automodule:: watchdog.observers


`watchdog.observers.polling`
============================

.. automodule:: watchdog.observers.polling


`watchdog.utils`
================

.. automodule:: watchdog.utils


`watchdog.utils.dirsnapshot`
============================

.. automodule:: watchdog.utils.dirsnapshot

`watchdog.tricks`
=================

.. automodule:: watchdog.tricks


.. toctree::
   :maxdepth: 2
